{% extends "admin/change_list.html" %}
{% load i18n admin_urls %}

{% block object-tools-items %}
    {% if not is_popup %}
        {% url cl.opts|admin_urlname:'model_history' as history_url %}
        <li><a href="{{ history_url }}">{% trans 'History' %}</a></li>
    {% endif %}
    {{ block.super }}
{% endblock %}

{% block content_title %}{% if history_model_opts %}{% else %}{{ block.super }}{% endif %}{% endblock %}
